[![Build status](https://github.com/twyleg/common_qml/actions/workflows/tests.yaml/badge.svg)]()
[![GitHub latest commit](https://badgen.net/github/last-commit/twyleg/common_qml)](https://GitHub.com/twyleg/common_qml/commit/)
[![PyPI download month](https://img.shields.io/pypi/dm/common-qml)](https://pypi.python.org/pypi/common-qml/)
[![PyPi version](https://badgen.net/pypi/v/common-qml/)](https://pypi.org/project/common-qml)
[![Documentation Status](https://readthedocs.org/projects/common-qml/badge/?version=latest)](http://common-qml.readthedocs.io/?badge=latest)


# common_qml

Ipsum Lorem

## Prerequisites

Add the following secrets for GitHub Actions:

* PYPI_API_TOKEN

## Examples

All examples can be found in the [examples/](https://github.com/twyleg/common_qml/tree/master/examples) directory.
